ETE2 - webplugin demonstration

Paste a tree in newick format and press "Draw tree":
((holA[&&NHX:species=chimp:confidence=50], holB[&&NHX:species=human:confidence=100]), holC[&&NHX:species=mouse:confidence=88]);
You can paste trees in newick (NH) and extended newick (NHX) formats. Features in NHX format will be parsed as tree features so you can add them as node faces to the tree image. features whose names starts by "_" will be ignored.